﻿/*Copyright 2024 Wojciech Krzysztof Fiałkiewicz

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"),
to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense,
and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.*/

using System;
using System.Windows.Forms;

namespace Fractals_Visualizer
{
    public partial class FractalsVisualizer : Form
    {
        private int WindowsCount { get; set; }

        public FractalsVisualizer()
        {
            InitializeComponent();
            WindowsCount = 0;
        }

        private void chaosToolStripMenuItem_Click(object sender, EventArgs e)
        {
            ChaosProperties cs = new ChaosProperties();

            cs.MdiParent = this;
            WindowsCount++;
            (cs as IWindowsCount).SetNumber(WindowsCount);
            cs.Show();
        }

        private void aboutToolStripMenuItem_Click(object sender, EventArgs e)
        {
            About a = new About();

            a.ShowDialog();
        }

        private void juliaSetOnComplexNumbersPlaneToolStripMenuItem_Click(object sender, EventArgs e)
        {
            JuliaSetProperties jsp = new JuliaSetProperties();

            jsp.MdiParent = this;
            WindowsCount++;
            (jsp as IWindowsCount).SetNumber(WindowsCount);
            jsp.Show();
        }

        private void mandelbrotSetOnComplexNumbersPlaneToolStripMenuItem_Click(object sender, EventArgs e)
        {
            MandelbrotSetProperties msp = new MandelbrotSetProperties();

            msp.MdiParent = this;
            WindowsCount++;
            (msp as IWindowsCount).SetNumber(WindowsCount);
            msp.Show();
        }

        private void juliaPythagorasSetOnComplexPythagorasPlaneToolStripMenuItem_Click(object sender, EventArgs e)
        {
            JuliaPythagorasSetProperties msp = new JuliaPythagorasSetProperties();

            msp.MdiParent = this;
            WindowsCount++;
            (msp as IWindowsCount).SetNumber(WindowsCount);
            msp.Show();
        }

        private void mandelbrotSetOnComplexPythagorasPlaneToolStripMenuItem_Click(object sender, EventArgs e)
        {
            MandelbrotPythagorasSetProperties msp = new MandelbrotPythagorasSetProperties();

            msp.MdiParent = this;
            WindowsCount++;
            (msp as IWindowsCount).SetNumber(WindowsCount);
            msp.Show();
        }

        private void setSizeToolStripMenuItem_Click(object sender, EventArgs e)
        {
            if(this.ActiveMdiChild is IFractal)
            {
                SizeInPixels sip = new SizeInPixels();

                sip.SizeWidth = ((IFractal)(this.ActiveMdiChild)).GetWidth();
                sip.SizeHeight = ((IFractal)(this.ActiveMdiChild)).GetHeight();
                if(sip.ShowDialog() == DialogResult.OK)
                {
                    ((IFractal)(this.ActiveMdiChild)).SetClientSize(sip.SizeWidth, sip.SizeHeight);
                    ((IFractal)(this.ActiveMdiChild)).DrawFractal();
                }
            }
        }

        private void setDeepToolStripMenuItem_Click(object sender, EventArgs e)
        {
            if (this.ActiveMdiChild is IFractal)
            {
                Deep d = new Deep();

                d.DeepValue = ((IFractal)(this.ActiveMdiChild)).GetDeep();
                if (d.ShowDialog() == DialogResult.OK)
                {
                    ((IFractal)(this.ActiveMdiChild)).SetDeep(d.DeepValue);
                    ((IFractal)(this.ActiveMdiChild)).DrawFractal();
                }
            }
        }

        private void saveFractalToolStripMenuItem_Click(object sender, EventArgs e)
        {
            if (this.ActiveMdiChild is IFractal)
            {
                ((IFractal)(this.ActiveMdiChild)).Save();
            }
        }

        private void saveFractalCustomSizeToolStripMenuItem_Click(object sender, EventArgs e)
        {
            if (this.ActiveMdiChild is IFractal)
            {
                JpgInPixels sip = new JpgInPixels();

                sip.SizeWidth = 3000;
                sip.SizeHeight = 3000;
                if (sip.ShowDialog() == DialogResult.OK)
                {
                    ((IFractal)(this.ActiveMdiChild)).SaveCustomSize(sip.SizeWidth, sip.SizeHeight);
                }
            }
        }
    }
}
 