﻿/*Copyright 2024 Wojciech Krzysztof Fiałkiewicz

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"),
to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense,
and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.*/

using System;

namespace Fractals_Visualizer
{
    internal class MandelbrotSet : Fractal
    {
        private Random m_Random;
        
        public MandelbrotSet()
        {
            base.Text = "Mandelbrot Set";
            m_Random = new Random();
        }

        protected override DisplayNumber DetermineNumber(ComplexNumber z, ComplexNumber c, int x, int y)
        {
            ComplexNumber zn;
            DisplayNumber dn = new DisplayNumber();

            dn.x = x;
            dn.y = y;

            zn = c;
            for (int i = 0; i <= Amount; i++)
            {
                double tr = 0.0;

                zn = zn * zn + z;
                tr = zn.R();
                if (!(double.IsNaN(tr) || double.IsNegativeInfinity(tr) || double.IsPositiveInfinity(tr) || double.IsInfinity(tr)))
                {
                    dn.R = tr;
                    dn.Nr = i;
                }
                if (dn.R > 2.0)
                {
                    if (!(dn.Escaped))
                    {
                        dn.r = dn.R;
                        dn.nr = dn.Nr;
                        dn.Escaped = true;
                    }
                }
            }
            return dn;
        }
    }
}
